__all__ = [
    "__title__",
    "__summary__",
    "__uri__",
    "__author__",
    "__email__",
    "__license__",
    "__copyright__",
]

__title__ = "vivarium_build_utils"
__summary__ = "Shared build utilities and Jenkins pipeline library for Simulation Science projects."
__uri__ = "https://github.com/ihmeuw/vivarium_build_utils"

__author__ = "The vivarium developers"
__email__ = "vivarium.dev@gmail.com"

__license__ = "BSD-3-Clause"
__copyright__ = f"Copyright 2025 {__author__}"
